==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/views/banner/BannerView.java <==
package com.yifan.yf_ads.views.banner;

import android.app.Activity;
import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RelativeLayout;

import androidx.annotation.NonNull;

import com.yifan.yf_ads.R;
import com.yifan.yf_ads.admanager.BannerAdManager;
import com.yifan.yf_ads.admanager.CommonAdManager;
import com.yifan.yf_ads.bean.BannerAdBean;
import com.yifan.yf_ads.utils.FLog;
import com.yifan.yf_ads.views.RoundedCornerLayout;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.platform.PlatformView;

public class BannerView implements PlatformView {
    private final String TAG = "BannerView";

    @NonNull
    private RelativeLayout containerView;

    private BannerAdManager bannerAdManager;

    // 请求广告的具体类

    BannerView(@NonNull Activity activity, int id, BannerAdBean creationParams, EventChannel.EventSink eventSink) {
        FLog.i(TAG, "BannerView id = " + id + " activity = " + activity);
        Context context = activity.getApplicationContext();
        containerView = new RelativeLayout(context);
        int cornerSize = 0;
        if (creationParams != null) {
            cornerSize = creationParams.getCornerSize();
        }
        FLog.i(TAG, "cornerSize = " + cornerSize);
//        containerView.setCornerRadius(cornerSize);
        bannerAdManager = new BannerAdManager(activity);
        bannerAdManager.setAdListener(new CommonAdManager.AdListener() {
            @Override
            public void onAdClose() {
                containerView.removeAllViews();
                final ViewGroup.LayoutParams layoutParams = containerView.getLayoutParams();
                layoutParams.height = 0;
                layoutParams.width = 0;
                containerView.setLayoutParams(layoutParams);
            }

            @Override
            public void onAdLoadSuccess() {
                bannerAdManager.showAd(activity, containerView);
            }

            @Override
            public void onAdLoadFail(String errorMessage) {
                FLog.i("bannerAdLoadFail " + errorMessage);
            }
        });
        bannerAdManager.requestBannerAd(id, creationParams, eventSink);
    }

    @NonNull
    @Override
    public View getView() {
        return containerView;
    }

    @Override
    public void dispose() {
        FLog.i(TAG, "dispose");
//        releaseAd();
    }

    public void releaseAd() {
        if (bannerAdManager != null) {
            bannerAdManager.destroy();
        }
    }
}

==> 0.0.8.tar.gz: android/src/main/java/com/yifan/yf_ads/views/banner/BannerView.java <==
package com.yifan.yf_ads.views.banner;

import android.app.Activity;
import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RelativeLayout;

import androidx.annotation.NonNull;

import com.yifan.yf_ads.R;
import com.yifan.yf_ads.admanager.BannerAdManager;
import com.yifan.yf_ads.admanager.CommonAdManager;
import com.yifan.yf_ads.bean.BannerAdBean;
import com.yifan.yf_ads.utils.FLog;
import com.yifan.yf_ads.views.RoundedCornerLayout;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.platform.PlatformView;

public class BannerView implements PlatformView {
    private final String TAG = "BannerView";

    @NonNull
    private RelativeLayout containerView;

    private BannerAdManager bannerAdManager;


    // 请求广告的具体类

    BannerView(@NonNull Activity activity, String id, BannerAdBean creationParams,
               EventChannel.EventSink eventSink, BannerCall bannerCall) {
        FLog.i(TAG, "BannerView id = " + id + " activity = " + activity);
        if (creationParams == null) {
            FLog.e(TAG, "BannerView creationParams is null, return.");
            return;
        }
        Context context = activity.getApplicationContext();
        containerView = new RelativeLayout(context);
        int cornerSize = creationParams.getCornerSize();
        FLog.i(TAG, "cornerSize = " + cornerSize);
//        containerView.setCornerRadius(cornerSize);
        bannerAdManager = new BannerAdManager(activity);
        bannerAdManager.setAdListener(new CommonAdManager.AdListener() {
            @Override
            public void onAdClose() {
                containerView.removeAllViews();
                final ViewGroup.LayoutParams layoutParams = containerView.getLayoutParams();
                layoutParams.height = 0;
                layoutParams.width = 0;
                containerView.setLayoutParams(layoutParams);
                if (bannerCall != null) {
                    bannerCall.onAdClose(id);
                }
            }

            @Override
            public void onAdLoadSuccess() {
                FLog.i("onAdLoadSuccess ");
                if (creationParams.isAutoShow()) {
                    showAd(activity);
                }
            }

            @Override
            public void onAdLoadFail(String errorMessage) {
                FLog.i("bannerAdLoadFail " + errorMessage);
            }
        });
        bannerAdManager.requestBannerAd(id, creationParams, eventSink);
    }

    public void showAd(@NonNull Activity activity) {
        if (bannerAdManager != null) {
            bannerAdManager.showAd(activity, containerView);
        }
    }

    @NonNull
    @Override
    public View getView() {
        return containerView;
    }

    @Override
    public void dispose() {
        FLog.i(TAG, "dispose");
//        releaseAd();
    }

    public void releaseAd() {
        if (bannerAdManager != null) {
            bannerAdManager.destroy();
        }
    }
}
